Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(951)

Unified Diff: media/base/media_format.cc

Issue 18546: Implementation of Pipeline and FilterHost interfaces. This is a large change... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 11 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « media/base/media_format.h ('k') | media/base/pipeline.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/base/media_format.cc
===================================================================
--- media/base/media_format.cc (revision 8731)
+++ media/base/media_format.cc (working copy)
@@ -8,10 +8,10 @@
namespace mime_type {
// Represents a URI, typically used to create a DataSourceInterface.
// Expected keys:
-// kUri String The URI
-const char kURI[] = "text/x-uri";
+// kURL String The URL
+const char kURL[] = "text/x-url";
// Represents a generic byte stream, typically from a DataSourceInterface.
// Expected keys:
@@ -44,11 +44,15 @@
// kHeight Integer Display height of the surface
const char kUncompressedVideo[] = "video/x-uncompressed";
+// Major types of media types begin with the prefix "audio/" or "video/".
+const char kMajorTypeVideo[] = "video/";
+const char kMajorTypeAudio[] = "audio/";
+
} // namespace mime_type
// Common keys.
const char MediaFormat::kMimeType[] = "MimeType";
-const char MediaFormat::kURI[] = "Uri";
+const char MediaFormat::kURL[] = "URL";
const char MediaFormat::kSurfaceFormat[] = "SurfaceFormat";
const char MediaFormat::kSampleRate[] = "SampleRate";
const char MediaFormat::kSampleBits[] = "SampleBits";
@@ -8,10 +8,10 @@
namespace mime_type {
-// Represents a URI, typically used to create a DataSourceInterface.
+// Represents a URL, typically used to create a DataSourceInterface.
// Expected keys:
« no previous file with comments | « media/base/media_format.h ('k') | media/base/pipeline.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698